sodium.ffi library

Classes

LibSodiumFFI
SodiumAllocator
An Allocator using the libsodium memory functionality.
SodiumInit
Static class to obtain a Sodium instance.
SodiumPointer<T extends NativeType>
A C-Pointer wrapper that uses the memory utilities of libsodium.
SodiumScope
A lexical scope that owns libsodium allocations and disposes every one it still owns, in reverse (LIFO) order, when the body returns or throws.
SodiumSumoInit
Static class to obtain a SodiumSumo instance.

Enums

MemoryProtection
The different levels of memory protection that libsodium provides.

Extensions

CharSodiumPtr on SodiumPointer<Char>
Extensions on specific sodium pointers for easy conversion to dart types
SodiumString on String
Extensions on String to add sodium pointer operations
TypedNumberListX on List<num>
Extensions on typed lists to add sodium pointer operations

Functions

sodiumScope<R>(LibSodiumFFI sodium, R body(SodiumScope scope)) → R
Runs body in a fresh SodiumScope, disposing everything the scope still owns, in reverse (LIFO) order, when body returns or throws.