SodiumSumoInit class sealed

Static class to obtain a SodiumSumo instance.

This initializer requires you to use the sumo variant of libsodium, which is the variant with the full API, including internals and rarely used APIs.

See https://libsodium.gitbook.io/doc/advanced for some of the advanced APIs

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

init() SodiumSumo
Creates a new SodiumSumo instance for the bundled libsodium.