init static method
Creates a new Sodium instance for the bundled libsodium.
This method will wait for sodium.js to load and then return the initialized instance.
Implementation
static Future<Sodium> init() async =>
initFromJS(await LibSodiumJSLoader.loadLibSodiumJS());