GenericHashConsumer class abstract interface

A typed StreamConsumer, which is used to generate a hash from a stream of data.

See GenericHash.createConsumer for more details.

Implemented types

Properties

hash → Future<Uint8List>
A future that resolves to the hash of the data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Uint8List data) → void
Adds data to the sink.
inherited
addStream(Stream<Uint8List> stream) → Future
Consumes the elements of stream.
inherited
close() → Future<Uint8List>
Closes the consumer and calculates the hash.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited