Kx class abstract interface

A meta class that provides access to all libsodium kx APIs.

This class provides the dart interface for the crypto operations documented in https://libsodium.gitbook.io/doc/key_exchange. Please refer to that documentation for more details about these APIs.

Properties

hashCode → int
The hash code for this object.
no setterinherited
publicKeyBytes → int
Provides crypto_kx_PUBLICKEYBYTES.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKeyBytes → int
Provides crypto_kx_SECRETKEYBYTES.
no setter
seedBytes → int
Provides crypto_kx_SEEDBYTES.
no setter
sessionKeyBytes → int
Provides crypto_kx_SESSIONKEYBYTES.
no setter

Methods

clientSessionKeys({required Uint8List clientPublicKey, required SecureKey clientSecretKey, required Uint8List serverPublicKey}) → SessionKeys
Provides crypto_kx_client_session_keys.
keyPair() → KeyPair
Provides crypto_kx_keypair.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seedKeyPair(SecureKey seed) → KeyPair
Provides crypto_kx_seed_keypair.
serverSessionKeys({required Uint8List serverPublicKey, required SecureKey serverSecretKey, required Uint8List clientPublicKey}) → SessionKeys
Provides crypto_kx_server_session_keys.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited