SecretStreamPlainMessage class sealed

A container class for a extended plain message before encryption.

Available extensions
Annotations
  • @freezed

Constructors

SecretStreamPlainMessage(Uint8List message, {Uint8List? additionalData, @Default.new(SecretStreamMessageTag.message) SecretStreamMessageTag tag})
Default constructor
const
factory

Properties

additionalData Uint8List?
Additional data, that should be used to generate authentication data.
no setterinherited
copyWith → $SecretStreamPlainMessageCopyWith<SecretStreamPlainMessage>
Create a copy of SecretStreamPlainMessage with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message Uint8List
The message that should be encrypted.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag SecretStreamMessageTag
The message tag that should be attached to the encrypted message.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SecretStreamPlainMessage value)) → TResult

Available on SecretStreamPlainMessage, provided by the SecretStreamPlainMessagePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SecretStreamPlainMessage value)?) → TResult?

Available on SecretStreamPlainMessage, provided by the SecretStreamPlainMessagePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SecretStreamPlainMessage value)?, {required TResult orElse()}) → TResult

Available on SecretStreamPlainMessage, provided by the SecretStreamPlainMessagePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Uint8List message, Uint8List? additionalData, SecretStreamMessageTag tag)?, {required TResult orElse()}) → TResult

Available on SecretStreamPlainMessage, provided by the SecretStreamPlainMessagePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Uint8List message, Uint8List? additionalData, SecretStreamMessageTag tag)) → TResult

Available on SecretStreamPlainMessage, provided by the SecretStreamPlainMessagePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Uint8List message, Uint8List? additionalData, SecretStreamMessageTag tag)?) → TResult?

Available on SecretStreamPlainMessage, provided by the SecretStreamPlainMessagePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited