CryptoSumo class abstract interface

A meta class that provides access to all libsodium sumo crypto APIs.

Implemented types

Properties

aeadAegis256 → Aead
An instance of Aead.
no setterinherited
aeadChaCha20Poly1305 → Aead
An instance of Aead.
no setterinherited
aeadXChaCha20Poly1305IETF → Aead
An instance of Aead.
no setterinherited
auth → Auth
An instance of Auth.
no setterinherited
box → Box
An instance of Box.
no setterinherited
genericHash → GenericHash
An instance of GenericHash.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ipcrypt → Ipcrypt
An instance of Ipcrypt.
no setterinherited
kdf → Kdf
An instance of Kdf.
no setterinherited
kdfHkdfSha256 → KdfHkdf
An instance of KdfHkdf.
no setterinherited
kdfHkdfSha512 → KdfHkdf
An instance of KdfHkdf.
no setterinherited
kem → Kem
An instance of Kem.
no setterinherited
kx → Kx
An instance of Kx.
no setterinherited
pwhash → Pwhash
An instance of Pwhash.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalarmult → Scalarmult
An instance of Scalarmult.
no setter
secretBox → SecretBox
An instance of SecretBox.
no setterinherited
secretStream → SecretStream
An instance of SecretStream.
no setterinherited
shortHash → ShortHash
An instance of ShortHash.
no setterinherited
sign → SignSumo
An instance of Sign.
no setteroverride
xofShake128 → Xof
An instance of Xof.
no setterinherited
xofShake256 → Xof
An instance of Xof.
no setterinherited
xofTurboshake128 → Xof
An instance of Xof.
no setterinherited
xofTurboshake256 → Xof
An instance of Xof.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited