SignSumo class abstract interface

A meta class that provides access to all libsodium sumo sign APIs.

This class provides the dart interface for the crypto operations documented in https://libsodium.gitbook.io/doc/public-key_cryptography/public-key_signatures. Please refer to that documentation for more details about these APIs.

Implemented types

Properties

bytes → int
Provides crypto_sign_BYTES.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
publicKeyBytes → int
Provides crypto_sign_PUBLICKEYBYTES.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretKeyBytes → int
Provides crypto_sign_SECRETKEYBYTES.
no setterinherited
seedBytes → int
Provides crypto_sign_SEEDBYTES.
no setterinherited

Methods

call({required Uint8List message, required SecureKey secretKey}) → Uint8List
Provides crypto_sign.
inherited
createConsumer({required SecureKey secretKey}) → SignatureConsumer
Creates a StreamConsumer for generating a signature from a stream.
inherited
createVerifyConsumer({required Uint8List signature, required Uint8List publicKey}) → VerificationConsumer
Creates a StreamConsumer for verifying a signature from a stream.
inherited
detached({required Uint8List message, required SecureKey secretKey}) → Uint8List
Provides crypto_sign_detached.
inherited
keyPair() → KeyPair
Provides crypto_sign_keypair.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({required Uint8List signedMessage, required Uint8List publicKey}) → Uint8List
Provides crypto_sign_open.
inherited
pkToCurve25519(Uint8List publicKey) → Uint8List
Provides crypto_sign_ed25519_pk_to_curve25519.
seedKeyPair(SecureKey seed) → KeyPair
Provides crypto_sign_seed_keypair.
inherited
skToCurve25519(SecureKey secretKey) → SecureKey
Provides crypto_sign_ed25519_sk_to_curve25519.
skToPk(SecureKey secretKey) → Uint8List
Provides crypto_sign_ed25519_sk_to_pk.
skToSeed(SecureKey secretKey) → SecureKey
Provides crypto_sign_ed25519_sk_to_seed.
stream({required Stream<Uint8List> messages, required SecureKey secretKey}) → Future<Uint8List>
Get the signature from an aynchronous stream of data.
inherited
toString() → String
A string representation of this object.
inherited
verifyDetached({required Uint8List message, required Uint8List signature, required Uint8List publicKey}) → bool
Provides crypto_sign_verify_detached.
inherited
verifyStream({required Stream<Uint8List> messages, required Uint8List signature, required Uint8List publicKey}) → Future<bool>
Validate the signature from an aynchronous stream of data.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited