SodiumSumo class abstract
A meta class that provides access to all toplevel libsodium sumo API groups.
- Implemented types
Properties
- crypto → CryptoSumo
-
An instance of Crypto.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- randombytes → Randombytes
-
An instance of Randombytes.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → SodiumVersion
-
Returns the version of the underlying libsodium implementation.
no setterinherited
Methods
-
createTransferrableKeyPair(
KeyPair keyPair) → TransferrableKeyPair -
Creates a boxed copy of the
keyPairthat can be transferred between isolates.inherited -
createTransferrableSecureKey(
SecureKey secureKey) → TransferrableSecureKey -
Creates a boxed copy of the
secureKeythat can be transferred between isolates.inherited -
materializeTransferrableKeyPair(
TransferrableKeyPair transferrableKeyPair) → KeyPair -
Extracts the KeyPair from the
transferrableKeyPair.inherited -
materializeTransferrableSecureKey(
TransferrableSecureKey transferrableSecureKey) → SecureKey -
Extracts the SecureKey from the
transferrableSecureKey.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pad(
Uint8List buf, int blocksize) → Uint8List -
Provides sodium_pad.
inherited
-
runIsolated<
T> (SodiumIsolateCallback< T> callback, {List<SecureKey> secureKeys = const [], List<KeyPair> keyPairs = const []}) → Future<T> -
Runs the given
callbackwith an isolate.inherited -
secureAlloc(
int length) → SecureKey -
Allocates new memory for a SecureKey of
lengthbytes.inherited -
secureCopy(
Uint8List data) → SecureKey -
Allocates new memory for a SecureKey and copies the data from
data.inherited -
secureRandom(
int length) → SecureKey -
Allocates new memory for a SecureKey and fills it with
lengthbytes of random data.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
unpad(
Uint8List buf, int blocksize) → Uint8List -
Provides sodium_unpad.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited