SodiumSumoUnavailable class

Exception that is thrown when the sumo variant of libsodium is not available

This can happen when trying to load SodiumSumo on the web, but only the normal variant of sodium.js is available.

Inheritance

Constructors

SodiumSumoUnavailable([String? originalMessage])
Default constructor.

Properties

hashCode int
The hash code for this object.
no setterinherited
originalMessage String?
The original error message, if one existed.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited