LibSodiumJSLoader class sealed
A helper class that interacts with sodium.js to get the loaded sodium instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadLibSodiumJS(
) → Future< LibSodiumJS> - Obtain the raw LibSodiumJS instance from the browser.