DetachedCipherResult class sealed
The result of a detached cipher operation. It consists of the actual
cipherText as well as the mac.
- Available extensions
- Annotations
-
- @freezed
Constructors
- DetachedCipherResult({required Uint8List cipherText, required Uint8List mac})
-
Default constructor.
constfactory
Properties
- cipherText → Uint8List
-
The encrypted data.
no setterinherited
-
copyWith
→ $DetachedCipherResultCopyWith<
DetachedCipherResult> -
Create a copy of DetachedCipherResult
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mac → Uint8List
-
The message authentication code of the data.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_DetachedCipherResult value)) → TResult -
Available on DetachedCipherResult, provided by the DetachedCipherResultPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_DetachedCipherResult value)?) → TResult? -
Available on DetachedCipherResult, provided by the DetachedCipherResultPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_DetachedCipherResult value)?, {required TResult orElse()}) → TResult -
Available on DetachedCipherResult, provided by the DetachedCipherResultPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Uint8List cipherText, Uint8List mac)?, {required TResult orElse()}) → TResult -
Available on DetachedCipherResult, provided by the DetachedCipherResultPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Uint8List cipherText, Uint8List mac)) → TResult -
Available on DetachedCipherResult, provided by the DetachedCipherResultPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Uint8List cipherText, Uint8List mac)?) → TResult? -
Available on DetachedCipherResult, provided by the DetachedCipherResultPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited