A meta class that provides access to all libsodium ipcrypt APIs.
This class provides the dart interface for the crypto operations documented in https://libsodium.gitbook.io/doc/secret-key_cryptography/ip_address_encryption Please refer to that documentation for more details about these APIs.
Properties
- bytes → int
-
Provides crypto_ipcrypt_BYTES.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyBytes → int
-
Provides crypto_ipcrypt_KEYBYTES.
no setter
- nd → IpcryptNd
-
Access to the nonce-dependent (nd) ipcrypt variant.
no setter
- ndx → IpcryptNd
-
Access to the nonce-dependent extended (ndx) ipcrypt variant.
no setter
- pfx → IpcryptPfx
-
Access to the prefix-preserving (pfx) ipcrypt variant.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decrypt(
{required Uint8List cipherText, required SecureKey key}) → IpAddress - Provides crypto_ipcrypt_decrypt.
-
encrypt(
{required IpAddress input, required SecureKey key}) → Uint8List - Provides crypto_ipcrypt_encrypt.
-
keygen(
) → SecureKey - Provides crypto_ipcrypt_keygen.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited