A meta class that provides access to all libsodium ipcrypt nonce-dependent APIs (nd and ndx variants).
This class provides the dart interface for the crypto operations documented in https://libsodium.gitbook.io/doc/secret-key_cryptography/ip_address_encryption Please refer to that documentation for more details about these APIs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputBytes → int
-
Provides crypto_ipcrypt_nd_INPUTBYTES / crypto_ipcrypt_ndx_INPUTBYTES.
no setter
- keyBytes → int
-
Provides crypto_ipcrypt_nd_KEYBYTES / crypto_ipcrypt_ndx_KEYBYTES.
no setter
- outputBytes → int
-
Provides crypto_ipcrypt_nd_OUTPUTBYTES / crypto_ipcrypt_ndx_OUTPUTBYTES.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tweakBytes → int
-
Provides crypto_ipcrypt_nd_TWEAKBYTES / crypto_ipcrypt_ndx_TWEAKBYTES.
no setter
Methods
-
decrypt(
{required Uint8List cipherText, required SecureKey key}) → IpAddress - Provides crypto_ipcrypt_nd_decrypt / crypto_ipcrypt_ndx_decrypt.
-
encrypt(
{required IpAddress input, required Uint8List tweak, required SecureKey key}) → Uint8List - Provides crypto_ipcrypt_nd_encrypt / crypto_ipcrypt_ndx_encrypt.
-
keygen(
) → SecureKey - Provides crypto_ipcrypt_nd_keygen / crypto_ipcrypt_ndx_keygen.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited