A meta class that provides access to all libsodium kdf_hkdf APIs.
This class provides the dart interface for the crypto operations documented in https://libsodium.gitbook.io/doc/key_derivation/hkdf. Please refer to that documentation for more details about these APIs.
This interface represents a single HKDF variant (either HKDF-SHA-256 or HKDF-SHA-512). The operations are identical for both variants; only the underlying hash function and the reported constant sizes differ.
Properties
- bytesMax → int
-
Provides crypto_kdf_hkdf_shaXXX_BYTES_MAX.
no setter
- bytesMin → int
-
Provides crypto_kdf_hkdf_shaXXX_BYTES_MIN.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyBytes → int
-
Provides crypto_kdf_hkdf_shaXXX_KEYBYTES.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createExtractConsumer(
{Uint8List? salt}) → KdfHkdfExtractConsumer - Provides crypto_kdf_hkdf_shaXXX_extract_init, _update and _final.
-
expand(
{required SecureKey masterKey, required String context, required int outLen}) → SecureKey - Provides crypto_kdf_hkdf_shaXXX_expand.
-
extract(
{Uint8List? salt, required Uint8List ikm}) → SecureKey - Provides crypto_kdf_hkdf_shaXXX_extract.
-
extractStream(
{Uint8List? salt, required Stream< Uint8List> ikm}) → Future<SecureKey> - Extract a master key from an asynchronous stream of input keying material.
-
keygen(
) → SecureKey - Provides crypto_kdf_hkdf_shaXXX_keygen.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited